﻿using LearnPodg.DataBase;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Text.RegularExpressions;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace LearnPodg
{
    /// <summary>
    /// Логика взаимодействия для ServicesList.xaml
    /// </summary>
    public partial class ServicesList : UserControl
    {
        private List<Service> services = new List<Service>();
        private List<Service> servicesAfterSortingFindingFiltring = new List<Service>();


        public ServicesList()
        {
            InitializeComponent();

            UploadServicesFromDB();
            FindingFiltringSorting();

            FiltringComboBox.SelectedIndex = 0;
            SortingComboBox.SelectedIndex = 0;
        }


        private List<Service> Filtring(List<Service> services)
        {
            switch (FiltringComboBox.SelectedIndex) 
            {
                case 0: return services;
                case 1: return new List<Service>(services.Where(a => a.Discount < 0.05));
                case 2: return new List<Service>(services.Where(a => a.Discount >= 0.05 && a.Discount < 0.15));
                case 3: return new List<Service>(services.Where(a => a.Discount >= 0.15 && a.Discount < 0.30));
                case 4: return new List<Service>(services.Where(a => a.Discount >= 0.30 && a.Discount < 0.70));
                case 5: return new List<Service>(services.Where(a => a.Discount >= 0.70 && a.Discount < 1));
            }
            return services;
        }

        private List<Service> Finding(List<Service> services) =>
            new List<Service>(services.Where(a => Regex.IsMatch(a.Title, FindingTextBox.Text) || Regex.IsMatch((a.Description == null)? "" : a.Description, FindingTextBox.Text)));

        private List<Service> Sorting(List<Service> services)
        {
            switch(SortingComboBox.SelectedIndex)
            {
                case 0: return new List<Service>(services.OrderBy(a => a.PriceAmount));
                case 1: return new List<Service>(services.OrderByDescending(a => a.PriceAmount));
            }
            return services;
        }

        private void UploadServicesFromDB()
        {
            using(Entities db = new Entities())
            {
                services = new List<Service>(db.Service.ToList());
            }
        }

        private void FindingFiltringSorting()
        {
            servicesAfterSortingFindingFiltring = Sorting(Finding(Filtring(services)));
            ServicesListView.ItemsSource = servicesAfterSortingFindingFiltring;
            UpdateDisplayServiceCount();
        }
        private void UpdateDisplayServiceCount() => 
            CountServiceDisplayer.Text = "" 
            + servicesAfterSortingFindingFiltring.Count 
            + " из " 
            + services.Count;
        #region UI Events
        private void FindingTextBox_TextChanged(object sender, TextChangedEventArgs e)
        {
            FindingFiltringSorting();
        }
        private void SortingComboBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            FindingFiltringSorting();
        }
        private void FiltringComboBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            FindingFiltringSorting();
        }
        private void EditServiceButton_Click(object sender, RoutedEventArgs e)
        {
            MainWindow.contentControl.Content = new AddingEditingService(Convert.ToInt32(((Button)sender).Uid));
        }
        private void AddServiceButton_Click(object sender, RoutedEventArgs e)
        {
            MainWindow.contentControl.Content = new AddingEditingService();
        }
        #endregion
    }
}
